#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Sep 11 07:56:48 2018
Practical 1 on Machine Learning Course, part 1: 
python script to display in a 3D view a 2-d normal law
@author: thierrychateau
"""

import numpy as np
import matplotlib.pyplot as plt
from scipy.stats import multivariate_normal
from mpl_toolkits.mplot3d import Axes3D

# plot a covariance 2D law in 3D
def plotGaus(mu,C, min_x=-2, max_x=2, min_y=-2,max_y=2):
    #Create grid and multivariate normal
    x = np.linspace(min_x,max_x,200)
    y = np.linspace(min_y,max_y,200)
    X, Y = np.meshgrid(x,y)
    pos = np.empty(X.shape + (2,))
    pos[:, :, 0] = X; pos[:, :, 1] = Y
    rv = multivariate_normal(mu, C)   
    #Make a 3D plot
    fig = plt.figure()
    ax = fig.gca(projection='3d')
    ax.plot_surface(X, Y, rv.pdf(pos),cmap='viridis',linewidth=0)
    ax.set_xlabel('X axis')
    ax.set_ylabel('Y axis')
    ax.set_zlabel('Z axis')


def main():
    #Parameters to set
    mu_x = 0
    mu_y = 0
    mu = np.array([mu_x, mu_y])
    C = np.array([[1, 1], \
                      [1, 2]])
    print("cov matrix = ", C)
    plotGaus(mu,C)
    plt.show()


if __name__ == "__main__":
    # execute only if run as a script
    main()
    
