#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Sep  9 08:36:33 2018
Machine learning practical 1 part 3
@author: thierrychateau
"""
from sklearn.naive_bayes import GaussianNB
import os
import numpy as np
from matplotlib import pyplot as plt
from matplotlib.colors import ListedColormap
from scipy.stats import multivariate_normal
from mpl_toolkits.mplot3d import Axes3D

import cv2
import pdb  #pdb.set_trace()
def getfeatures (path, cl):
    X = []
    scl = 'c'+str(cl)
    for i in os.listdir(path):
        print("processing file ",i)
        if os.path.isfile(os.path.join(path,i)) and scl in i:
            X.append(getfeature(path,i))
    return np.asarray(X)
def getfeature(path,filename):
    im = cv2.imread(path+filename)
    imrgb = cv2.cvtColor(im, cv2.COLOR_BGR2HSV)
    #plt.imshow(imrgb)
    #plt.title(filename)
    #vis.matplot(plt)
    R = imrgb[:,:,0]
    G = imrgb[:,:,1]
    B = imrgb[:,:,2]
    # normalize
    In= R+G+B
    mIn = np.max((In.flatten()))
    Rn = R/mIn
    Gn = G/mIn
    Bn = B/mIn
    # Compute mean of each component
    X = [np.mean(Rn.flatten()),np.mean(Gn.flatten()),np.mean(Bn.flatten())]
    return X

def main():
    #vis = visdom.Visdom()
    training_images_path ='images/dataset1/app/'
    testing_images_path ='images/dataset1/test/'
    X1 = getfeatures(training_images_path, 1)
    X1 = X1[:,0:2]
    X2 = getfeatures(training_images_path, 2)
    X2 = X2[:,0:2]
    Xtest1 = getfeatures(testing_images_path, 1)
    Xtest1 = Xtest1[:,0:2]
    Xtest2 = getfeatures(testing_images_path, 2)
    Xtest2 = Xtest2[:,0:2]
    Xtrain = np.concatenate((X1,X2),axis = 0)
    Xtest = np.concatenate((Xtest1,Xtest2),axis = 0)
    Y = np.concatenate((np.ones((X1.shape[0],1)) , 2*np.ones((X2.shape[0],1))),axis = 0)
    clf = GaussianNB(priors = [0.5,0.5])
    Y = Y.ravel()
    Ytrain = Y
    Ytest = Y
    clf.fit(Xtrain, Ytrain)
    score = clf.score(Xtest, Ytest)
    score_train = clf.score(Xtrain, Ytrain)
    print("prediction test1", clf.predict(Xtest1))
    print("prediction test1", clf.predict(Xtest2))
    print("Y = ", Y)
    print("X1 = ",X1)
    print("X2 = ",X2)
    #print("X3 = ",X3)
    # display
    #plt.plot(X1[:,0],X1[:,1],'+')
    #plt.plot(X2[:,0],X2[:,1],'o')
    h = .005  # step size in the mesh
    cm = plt.cm.RdBu
    cm_bright = ListedColormap(['#FF0000', '#0000FF'])
    x_min, x_max = Xtrain[:, 0].min() - .5, Xtrain[:, 0].max() + .5
    y_min, y_max = Xtrain[:, 1].min() - .5, Xtrain[:, 1].max() + .5
    xx, yy = np.meshgrid(np.arange(x_min, x_max, h),
                         np.arange(y_min, y_max, h))
    #pdb.set_trace()
    Z = clf.predict_proba(np.c_[xx.ravel(), yy.ravel()])[:, 1]
    #Z = clf.score(xx.ravel(), yy.ravel())
    #
    # Display
    #
    # Put the result into a color plot
    Z = Z.reshape(xx.shape)
    ax1 = plt.subplot(121)
    ax2 = plt.subplot(122,projection='3d')
    ax1.contourf(xx, yy, Z, cmap=cm, alpha=.8)
    # Plot also the training points
    ax1.scatter(Xtrain[:, 0], Xtrain[:, 1], c=Ytrain, cmap=cm_bright,
               edgecolors='k')
    # and testing points
    ax1.scatter(Xtest[:, 0], Xtest[:, 1], c=Ytest, cmap=cm_bright,
               edgecolors='k', alpha=0.6)
    ax1.set_xlim(xx.min(), xx.max())
    ax1.set_ylim(yy.min(), yy.max())
    ax1.set_xticks(())
    ax1.set_yticks(())
    ax1.set_title("Naive Bayes Gaussian classifier")
    ax1.text(xx.max() - .3, yy.min() + .3, ('test: %.2f' % score).lstrip('0'),
            size=15, horizontalalignment='right')
    ax1.text(xx.max() - .3, yy.min() + .9, ('train: %.2f' % score_train).lstrip('0'),
            size=15, horizontalalignment='right')
    #Make a 3D plot
    #ax2 = fig.gca(projection='3d')
    ax2.plot_surface(xx,yy, Z,cmap='viridis',linewidth=0)
    ax2.set_xlabel('X axis')
    ax2.set_ylabel('Y axis')
    ax2.set_zlabel('Z axis')
    ax2.set_title('Decision function for class 1 in 3D')
    plt.show()
if __name__ == "__main__":
    # execute only if run as a script
    main()
    

